@@ -27,7 +27,6 @@ Copyright (c) Intel Corporation (2009-2017).
 #include "llvm/Option/ArgList.h"
 #include "llvm/Option/Option.h"
 #include "clang/Basic/OpenCLOptions.h"
-#include "LLVMSPIRVOpts.h"
 
 #include <list>
 
@@ -44,6 +43,14 @@ enum COMPILE_OPT_ID {
 #undef PREFIX
 };
 
+#define OPTTABLE_STR_TABLE_CODE
+#include "opencl_clang_options.inc"
+#undef OPTTABLE_STR_TABLE_CODE
+
+#define OPTTABLE_PREFIXES_TABLE_CODE
+#include "opencl_clang_options.inc"
+#undef OPTTABLE_PREFIXES_TABLE_CODE
+
 typedef std::list<std::string> ArgsVector;
 
 //
@@ -100,7 +107,7 @@ private:
 class OpenCLOptTable : public llvm::opt::GenericOptTable {
 public:
   OpenCLOptTable(llvm::ArrayRef<Info> pOptionInfos)
-      : llvm::opt::GenericOptTable(pOptionInfos) {}
+      : llvm::opt::GenericOptTable(OptionStrTable, OptionPrefixesTable, pOptionInfos) {}
 
   OpenCLArgList *ParseArgs(const char *szOptions, unsigned &missingArgIndex,
                            unsigned &missingArgCount) const;
@@ -153,7 +160,7 @@ public:
   // Validates and prepares the effective options to pass to clang upon
   // compilation
   //
-  int processOptions(const char *pszOptions, const char *pszOptionsEx);
+  void processOptions(const char *pszOptions, const char *pszOptionsEx);
 
   //
   // Just validates the user supplied OpenCL compile options
@@ -179,13 +186,6 @@ public:
   std::string getEffectiveOptionsAsString() const;
 
   bool hasEmitSPIRV() const { return m_emitSPIRV; }
-
-  bool hasSPIRVExt() const { return m_hasSPIRVExt; }
-
-  SPIRV::TranslatorOpts::ExtensionsStatusMap getSPIRVExtStatusMap() const {
-    return m_SPIRVExtStatusMap;
-  }
-
   bool hasOptDisable() const { return m_optDisable; }
 
 private:
@@ -195,8 +195,6 @@ private:
   llvm::SmallVector<const char *, 16> m_effectiveArgsRaw;
   std::string m_sourceName;
   bool m_emitSPIRV;
-  bool m_hasSPIRVExt = false;
-  SPIRV::TranslatorOpts::ExtensionsStatusMap m_SPIRVExtStatusMap = {};
   bool m_optDisable;
 };
 
